```
[2025-03-02T04:28:44.645+0000] {anthropic_provider.py:93} INFO - Request parameters: {"model": "claude-3-5-haiku-20241022", "messages": [{"role": "user", "content": "<system>\nYou are Airflow Wingman, a helpful AI assistant integrated into Apache Airflow.\nYou have deep knowledge of Apache Airflow's architecture, DAGs, operators, and best practices.\nThe Airflow version being used is >=2.10.\n\nYou have access to Airflow MCP tools that you can use to fetch information and help users understand\nand manage their Airflow environment.\n\nWhen a user asks about Airflow functionality, consider using the appropriate tool to provide\naccurate and up-to-date information rather than relying solely on your training data.\n\n</system>"}, {"role": "user", "content": "list-dags"}], "temperature": 0.7, "max_tokens": 4096, "stream": true, "tools": 
[{"name": "get_connections", "description": "get_connections", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_connections_input", "type": "object"}}, {"name": "get_connection", "description": "get_connection", "input_schema": {"properties": {"connection_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Connection Id"}}, "title": "get_connection_input", "type": "object"}}, {"name": "get_dags", "description": "get_dags", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}, "tags": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Tags"}, "only_active": {"anyOf": [{"type": "boolean"}, {"type": "null"}], "default": null, "title": "Only Active"}, "paused": {"anyOf": [{"type": "boolean"}, {"type": "null"}], "default": null, "title": "Paused"}, "fields": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Fields"}, "dag_id_pattern": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id Pattern"}}, "title": "get_dags_input", "type": "object"}}, {"name": "get_dag", "description": "get_dag", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "fields": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Fields"}}, "title": "get_dag_input", "type": "object"}}, {"name": "get_task_instance_dependencies", "description": "get_task_instance_dependencies", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}}, "title": "get_task_instance_dependencies_input", "type": "object"}}, {"name": "get_mapped_task_instance_dependencies", "description": "get_mapped_task_instance_dependencies", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "map_index": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Map Index"}}, "title": "get_mapped_task_instance_dependencies_input", "type": "object"}}, {"name": "get_dag_runs", "description": "get_dag_runs", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "execution_date_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Execution Date Gte"}, "execution_date_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Execution Date Lte"}, "start_date_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Start Date Gte"}, "start_date_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Start Date Lte"}, "end_date_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "End Date Gte"}, "end_date_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "End Date Lte"}, "updated_at_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Updated At Gte"}, "updated_at_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Updated At Lte"}, "state": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "State"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}, "fields": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Fields"}}, "title": "get_dag_runs_input", "type": "object"}}, {"name": "get_dag_run", "description": "get_dag_run", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "fields": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Fields"}}, "title": "get_dag_run_input", "type": "object"}}, {"name": "get_upstream_dataset_events", "description": "get_upstream_dataset_events", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}}, "title": "get_upstream_dataset_events_input", "type": "object"}}, {"name": "get_dag_dataset_queued_event", "description": "get_dag_dataset_queued_event", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "uri": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Uri"}, "before": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Before"}}, "title": "get_dag_dataset_queued_event_input", "type": "object"}}, {"name": "get_dag_dataset_queued_events", "description": "get_dag_dataset_queued_events", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "before": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Before"}}, "title": "get_dag_dataset_queued_events_input", "type": "object"}}, {"name": "get_dataset_queued_events", "description": "get_dataset_queued_events", "input_schema": {"properties": {"uri": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Uri"}, "before": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Before"}}, "title": "get_dataset_queued_events_input", "type": "object"}}, {"name": "get_event_logs", "description": "get_event_logs", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}, "dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Run Id"}, "map_index": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Map Index"}, "try_number": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Try Number"}, "event": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Event"}, "owner": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Owner"}, "before": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Before"}, "after": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "After"}, "included_events": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Included Events"}, "excluded_events": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Excluded Events"}}, "title": "get_event_logs_input", "type": "object"}}, {"name": "get_event_log", "description": "get_event_log", "input_schema": {"properties": {"event_log_id": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Event Log Id"}}, "title": "get_event_log_input", "type": "object"}}, {"name": "get_import_errors", "description": "get_import_errors", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_import_errors_input", "type": "object"}}, {"name": "get_import_error", "description": "get_import_error", "input_schema": {"properties": {"import_error_id": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Import Error Id"}}, "title": "get_import_error_input", "type": "object"}}, {"name": "get_pools", "description": "get_pools", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_pools_input", "type": "object"}}, {"name": "get_pool", "description": "get_pool", "input_schema": {"properties": {"pool_name": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Pool Name"}}, "title": "get_pool_input", "type": "object"}}, {"name": "get_providers", "description": "get_providers", "input_schema": {"properties": {}, "title": "get_providers_input", "type": "object"}}, {"name": "get_task_instances", "description": "get_task_instances", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "execution_date_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Execution Date Gte"}, "execution_date_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Execution Date Lte"}, "start_date_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Start Date Gte"}, "start_date_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Start Date Lte"}, "end_date_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "End Date Gte"}, "end_date_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "End Date Lte"}, "updated_at_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Updated At Gte"}, "updated_at_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Updated At Lte"}, "duration_gte": {"anyOf": [{"type": "number"}, {"type": "null"}], "default": null, "title": "Duration Gte"}, "duration_lte": {"anyOf": [{"type": "number"}, {"type": "null"}], "default": null, "title": "Duration Lte"}, "state": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "State"}, "pool": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Pool"}, "queue": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Queue"}, "executor": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Executor"}, "limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}}, "title": "get_task_instances_input", "type": "object"}}, {"name": "get_task_instance", "description": "get_task_instance", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}}, "title": "get_task_instance_input", "type": "object"}}, {"name": "get_mapped_task_instance", "description": "get_mapped_task_instance", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "map_index": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Map Index"}}, "title": "get_mapped_task_instance_input", "type": "object"}}, {"name": "get_mapped_task_instances", "description": "get_mapped_task_instances", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "execution_date_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Execution Date Gte"}, "execution_date_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Execution Date Lte"}, "start_date_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Start Date Gte"}, "start_date_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Start Date Lte"}, "end_date_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "End Date Gte"}, "end_date_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "End Date Lte"}, "updated_at_gte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Updated At Gte"}, "updated_at_lte": {"anyOf": [{"format": "date-time", "type": "string"}, {"type": "null"}], "default": null, "title": "Updated At Lte"}, "duration_gte": {"anyOf": [{"type": "number"}, {"type": "null"}], "default": null, "title": "Duration Gte"}, "duration_lte": {"anyOf": [{"type": "number"}, {"type": "null"}], "default": null, "title": "Duration Lte"}, "state": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "State"}, "pool": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Pool"}, "queue": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Queue"}, "executor": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Executor"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_mapped_task_instances_input", "type": "object"}}, {"name": "get_task_instance_try_details", "description": "get_task_instance_try_details", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "task_try_number": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Task Try Number"}}, "title": "get_task_instance_try_details_input", "type": "object"}}, {"name": "get_task_instance_tries", "description": "get_task_instance_tries", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_task_instance_tries_input", "type": "object"}}, {"name": "get_mapped_task_instance_tries", "description": "get_mapped_task_instance_tries", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "map_index": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Map Index"}, "limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_mapped_task_instance_tries_input", "type": "object"}}, {"name": "get_mapped_task_instance_try_details", "description": "get_mapped_task_instance_try_details", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "map_index": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Map Index"}, "task_try_number": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Task Try Number"}}, "title": "get_mapped_task_instance_try_details_input", "type": "object"}}, {"name": "get_variables", "description": "get_variables", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_variables_input", "type": "object"}}, {"name": "get_variable", "description": "get_variable", "input_schema": {"properties": {"variable_key": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Variable Key"}}, "title": "get_variable_input", "type": "object"}}, {"name": "get_xcom_entries", "description": "get_xcom_entries", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "map_index": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Map Index"}, "xcom_key": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Xcom Key"}, "limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}}, "title": "get_xcom_entries_input", "type": "object"}}, {"name": "get_xcom_entry", "description": "get_xcom_entry", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "xcom_key": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Xcom Key"}, "map_index": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Map Index"}, "deserialize": {"anyOf": [{"type": "boolean"}, {"type": "null"}], "default": null, "title": "Deserialize"}, "stringify": {"anyOf": [{"type": "boolean"}, {"type": "null"}], "default": null, "title": "Stringify"}}, "title": "get_xcom_entry_input", "type": "object"}}, {"name": "get_extra_links", "description": "get_extra_links", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}}, "title": "get_extra_links_input", "type": "object"}}, {"name": "get_log", "description": "get_log", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "dag_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Run Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}, "task_try_number": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Task Try Number"}, "full_content": {"anyOf": [{"type": "boolean"}, {"type": "null"}], "default": null, "title": "Full Content"}, "map_index": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Map Index"}, "token": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Token"}}, "title": "get_log_input", "type": "object"}}, {"name": "get_dag_details", "description": "get_dag_details", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "fields": {"anyOf": [{"items": {}, "type": "array"}, {"type": "null"}], "default": null, "title": "Fields"}}, "title": "get_dag_details_input", "type": "object"}}, {"name": "get_tasks", "description": "get_tasks", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_tasks_input", "type": "object"}}, {"name": "get_task", "description": "get_task", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Task Id"}}, "title": "get_task_input", "type": "object"}}, {"name": "get_dag_stats", "description": "get_dag_stats", "input_schema": {"properties": {"dag_ids": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Ids"}}, "title": "get_dag_stats_input", "type": "object"}}, {"name": "get_dag_source", "description": "get_dag_source", "input_schema": {"properties": {"file_token": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "File Token"}}, "title": "get_dag_source_input", "type": "object"}}, {"name": "get_dag_warnings", "description": "get_dag_warnings", "input_schema": {"properties": {"dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Id"}, "warning_type": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Warning Type"}, "limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_dag_warnings_input", "type": "object"}}, {"name": "get_datasets", "description": "get_datasets", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}, "uri_pattern": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Uri Pattern"}, "dag_ids": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Dag Ids"}}, "title": "get_datasets_input", "type": "object"}}, {"name": "get_dataset", "description": "get_dataset", "input_schema": {"properties": {"uri": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Uri"}}, "title": "get_dataset_input", "type": "object"}}, {"name": "get_dataset_events", "description": "get_dataset_events", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}, "dataset_id": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Dataset Id"}, "source_dag_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Source Dag Id"}, "source_task_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Source Task Id"}, "source_run_id": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Source Run Id"}, "source_map_index": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Source Map Index"}}, "title": "get_dataset_events_input", "type": "object"}}, {"name": "get_config", "description": "get_config", "input_schema": {"properties": {"section": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Section"}}, "title": "get_config_input", "type": "object"}}, {"name": "get_value", "description": "get_value", "input_schema": {"properties": {"section": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Section"}, "option": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Option"}}, "title": "get_value_input", "type": "object"}}, {"name": "get_health", "description": "get_health", "input_schema": {"properties": {}, "title": "get_health_input", "type": "object"}}, {"name": "get_version", "description": "get_version", "input_schema": {"properties": {}, "title": "get_version_input", "type": "object"}}, {"name": "get_plugins", "description": "get_plugins", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}}, "title": "get_plugins_input", "type": "object"}}, {"name": "get_roles", "description": "get_roles", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_roles_input", "type": "object"}}, {"name": "get_role", "description": "get_role", "input_schema": {"properties": {"role_name": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Role Name"}}, "title": "get_role_input", "type": "object"}}, {"name": "get_permissions", "description": "get_permissions", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}}, "title": "get_permissions_input", "type": "object"}}, {"name": "get_users", "description": "get_users", "input_schema": {"properties": {"limit": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Limit"}, "offset": {"anyOf": [{"type": "integer"}, {"type": "null"}], "default": null, "title": "Offset"}, "order_by": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Order By"}}, "title": "get_users_input", "type": "object"}}, {"name": "get_user", "description": "get_user", "input_schema": {"properties": {"username": {"anyOf": [{"type": "string"}, {"type": "null"}], "default": null, "title": "Username"}}, "title": "get_user_input", "type": "object"}}]}
```